using System;
using System.Collections.Generic;
using System.Text;
using System.IO;
using System.Diagnostics;
using System.Text.RegularExpressions;

namespace QD_GUI
{
    public class QDInfo
    {
        /* <!ELEMENT qdinfo               (#PCDATA)>
         * 
         * <qdinfo>25 November 2006 (update-qd.pl)</qdinfo>
         * 
         * QueueDump.QDInfo.Date
         * QueueDump.QDinfo.MaintainedBy
         * QueueDump.QDInfo.FunctionalRevision
         */

        private string sDate = "";
        private string sMaintainedBy = "";
        private string sFunctionalRevision = "";

        #region Properties

        public string Date
        {
            get
            {
                return sDate;
            }
            set
            {
                sDate = value;
            }
        }

        public string MaintainedBy
        {
            get
            {
                return sMaintainedBy;
            }
            set
            {
                sMaintainedBy = value;
            }
        }

        public string FunctionalRevision
        {
            get
            {
                return sFunctionalRevision;
            }
            set
            {
                sFunctionalRevision = value;
            }
        }

        #endregion Properties

        #region Public Static Methods

        public static QDInfo ParseFile(string vsFile, QDInfo roQDInfo)
        {
            if (File.Exists(vsFile))
            {
                try
                {
                    Debug.WriteLine("Reading file: " + vsFile);

                    // Create an instance of StreamReader to read from a file.
                    // The using statement also closes the StreamReader.
                    using (StreamReader oStreamReader = new StreamReader(vsFile))
                    {
                        string sLine;
                        string sRegex;
                        Match oMatch;
                        // Read and process lines from the file until the end of 
                        // the file is reached.
                        while ((sLine = oStreamReader.ReadLine()) != null)
                        {
                            Debug.WriteLine(sLine);
                            // # Latest functional revision number of "qd"
                            //
                            // fr 050
                            sRegex = @"^fr \d+";
                            oMatch = Regex.Match(sLine, sRegex);
                            if(!String.IsNullOrEmpty(oMatch.Value))
                            {
                                roQDInfo.FunctionalRevision = oMatch.Value.Substring(3, oMatch.Value.Length - 3);
                            }
                        }
                    }
                }
                catch (Exception e)
                {
                    // Let the user know what went wrong.
                    Debug.WriteLine("The file could not be read:");
                    Debug.WriteLine(e.Message);
                }
            }
            else
            {
                throw new Exception("File does not exist: " + vsFile);
            }

            return roQDInfo;
        }

        public static QDInfo ParseQDInfoString(string vsQDInfo)
        {
            QDInfo oQDInfo = new QDInfo();

            // 25 November 2006 (update-qd.pl)

            // 25 November 2006
            string sRegex = @"^\d+ \w+ \d+";
            Match oMatch = Regex.Match(vsQDInfo, sRegex);
            if(!String.IsNullOrEmpty(oMatch.Value)) 
            {
                oQDInfo.Date = oMatch.Value;
            }

            // (update-qd.pl)
            sRegex = @"\(.*?\)$";
            oMatch = Regex.Match(vsQDInfo, sRegex);
            if(!String.IsNullOrEmpty(oMatch.Value))
            {
                oQDInfo.MaintainedBy = oMatch.Value.Substring(1, oMatch.Value.Length - 2);
            }

            return oQDInfo;
        }

        #endregion Public Static Methods
    }
}
